searchData={"items":[{"type":"module","title":"GPXEr","doc":"Implements high level functions for working with GPX files. The gpx struct is a wrapper around the gpx data and implements the Access behaviour. This means that you can use the Access/Kernel functions to access the data.\n\nIt also implements some helper functions for working with the track data.","ref":"GPXEr.html"},{"type":"module","title":"Examples - GPXEr","doc":"```elixir\n{:ok, doc} = GPXEr.load(\"test/test.gpx\")\nKernel.get_in(doc, [:name]) == \"Capital Ring\"\ndoc = Kernel.put_in(doc, [:name], \"Test\")\nKernel.get_in(doc, [:name]) == \"Test\"\n```\n\n```elixir\n{:ok, gpx} = GPXEr.load(\"test/test.gpx\")\n# TODO: Add example for Track map\n```\n```elixir\n{:ok, gpx} = GPXEr.load(\"test/test.gpx\")\n# Add distance data to the gpx data\ngpx = GPXEr.Track.put_in_distance(gpx)\n# TODO: Add example for Track map\n```","ref":"GPXEr.html#module-examples"},{"type":"function","title":"GPXEr.haversine_distance/2","doc":"Calculates the great-circle distance between two GPS/GPX points\non the Earth's surface (specified in kilometers).\n\nThe two points must be specified as {latitude, longitude} tuples.","ref":"GPXEr.html#haversine_distance/2"},{"type":"function","title":"GPXEr.load/1","doc":"Load a GPX file from a file path. Returns a tuple of {:ok, gpx} or {:error, reason}","ref":"GPXEr.html#load/1"},{"type":"function","title":"GPXEr.save/2","doc":"Saves a GPX struct to the give file path in the gpx format. Returns a tuple of :ok or {:error, reason}","ref":"GPXEr.html#save/2"},{"type":"module","title":"GPXEr.Element","doc":"Implements the Access behaviour for GPX elements.","ref":"GPXEr.Element.html"},{"type":"function","title":"GPXEr.Element.new/1","doc":"","ref":"GPXEr.Element.html#new/1"},{"type":"type","title":"GPXEr.Element.t/0","doc":"","ref":"GPXEr.Element.html#t:t/0"},{"type":"module","title":"GPXEr.Route","doc":"","ref":"GPXEr.Route.html"},{"type":"function","title":"GPXEr.Route.from_enum/2","doc":"","ref":"GPXEr.Route.html#from_enum/2"},{"type":"function","title":"GPXEr.Route.to_enum/1","doc":"","ref":"GPXEr.Route.html#to_enum/1"},{"type":"module","title":"GPXEr.Route.Element","doc":"","ref":"GPXEr.Route.Element.html"},{"type":"type","title":"GPXEr.Route.Element.t/0","doc":"","ref":"GPXEr.Route.Element.html#t:t/0"},{"type":"module","title":"GPXEr.Schema","doc":"Implements get and put from GPX elements based on their schema. This module is an internal module and should in general not be used directly. Instead use the Access behaviour implemented by the `GPXEr.Element` module.","ref":"GPXEr.Schema.html"},{"type":"function","title":"GPXEr.Schema.get/2","doc":"","ref":"GPXEr.Schema.html#get/2"},{"type":"function","title":"GPXEr.Schema.is_gpx/1","doc":"","ref":"GPXEr.Schema.html#is_gpx/1"},{"type":"function","title":"GPXEr.Schema.is_link/1","doc":"","ref":"GPXEr.Schema.html#is_link/1"},{"type":"function","title":"GPXEr.Schema.is_metadata/1","doc":"","ref":"GPXEr.Schema.html#is_metadata/1"},{"type":"function","title":"GPXEr.Schema.is_root/1","doc":"","ref":"GPXEr.Schema.html#is_root/1"},{"type":"function","title":"GPXEr.Schema.is_rte/1","doc":"","ref":"GPXEr.Schema.html#is_rte/1"},{"type":"function","title":"GPXEr.Schema.is_trk/1","doc":"","ref":"GPXEr.Schema.html#is_trk/1"},{"type":"function","title":"GPXEr.Schema.is_trkseg/1","doc":"","ref":"GPXEr.Schema.html#is_trkseg/1"},{"type":"function","title":"GPXEr.Schema.is_wpt/1","doc":"","ref":"GPXEr.Schema.html#is_wpt/1"},{"type":"function","title":"GPXEr.Schema.put/3","doc":"","ref":"GPXEr.Schema.html#put/3"},{"type":"module","title":"GPXEr.Track","doc":"","ref":"GPXEr.Track.html"},{"type":"function","title":"GPXEr.Track.break_at/2","doc":"","ref":"GPXEr.Track.html#break_at/2"},{"type":"function","title":"GPXEr.Track.break_into_segments_at/2","doc":"","ref":"GPXEr.Track.html#break_into_segments_at/2"},{"type":"function","title":"GPXEr.Track.flatten/1","doc":"If the given gpx document contains multiple tracks or segments this will \"flatten\" it into a single track.","ref":"GPXEr.Track.html#flatten/1"},{"type":"function","title":"GPXEr.Track.from_enum/2","doc":"","ref":"GPXEr.Track.html#from_enum/2"},{"type":"function","title":"GPXEr.Track.to_enum/1","doc":"","ref":"GPXEr.Track.html#to_enum/1"},{"type":"function","title":"GPXEr.Track.with_info/2","doc":"Calculate the distance, ascent and descent in for each track point.\n\nTakes a function, which will be pass the Track.Element and the info. All stats are returned as a tuple, with the first element\nthe total value over all tracks, the second the value for the current track and the third the value for the current track segment.","ref":"GPXEr.Track.html#with_info/2"},{"type":"module","title":"GPXEr.Track.Collectable","doc":"","ref":"GPXEr.Track.Collectable.html"},{"type":"function","title":"GPXEr.Track.Collectable.new/1","doc":"","ref":"GPXEr.Track.Collectable.html#new/1"},{"type":"module","title":"GPXEr.Track.Element","doc":"","ref":"GPXEr.Track.Element.html"},{"type":"type","title":"GPXEr.Track.Element.t/0","doc":"","ref":"GPXEr.Track.Element.html#t:t/0"},{"type":"module","title":"GPXEr.Track.Enumerator","doc":"","ref":"GPXEr.Track.Enumerator.html"},{"type":"function","title":"GPXEr.Track.Enumerator.new/1","doc":"","ref":"GPXEr.Track.Enumerator.html#new/1"},{"type":"function","title":"GPXEr.Track.Enumerator.next/1","doc":"","ref":"GPXEr.Track.Enumerator.html#next/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}